package ru.bitheaven.donpayintegplug.config;

import org.yaml.snakeyaml.DumperOptions;
import org.yaml.snakeyaml.LoaderOptions;
import org.yaml.snakeyaml.Yaml;
import org.yaml.snakeyaml.constructor.Constructor;

import java.io.*;
import java.util.logging.Logger;

public class ConfigHandler {

    private static String PATH;

    public static void register(Logger logger, String path) {
        new File(path).mkdir();
        PATH = path + "/config.yaml";

        if(!new File(PATH).exists())
            std(logger);
    }

    public static Config load() {
        LoaderOptions loaderOptions = new LoaderOptions();
        loaderOptions.setTagInspector(tag -> tag.getClassName().equals(Config.class.getName()));
        Yaml yaml = new Yaml(new Constructor(Config.class, loaderOptions));
        Config config;
        try {
            config = yaml.load(new FileInputStream(PATH));
        } catch (FileNotFoundException e) {
            throw new RuntimeException(e);
        }

        return config;
    }

    public static void save(Config config) {
        DumperOptions options = new DumperOptions();
        options.setIndent(2);
        options.setPrettyFlow(true);
        options.setDefaultFlowStyle(DumperOptions.FlowStyle.BLOCK);
        Yaml yaml = new Yaml(options);

        try {
            yaml.dump(config, new FileWriter(PATH));
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    public static void std(Logger logger) {
        save(new Config());
        logger.info("Created new config file");
    }
}